import { Input } from '@angular/core';
var BootstrapDirective = (function () {
    function BootstrapDirective(renderer, elementRef, initClasses, allowedTags) {
        if (allowedTags === void 0) { allowedTags = ['DIV']; }
        this.renderer = renderer;
        this.elementRef = elementRef;
        this.initClasses = initClasses;
        this.allowedTags = allowedTags;
        this._display = null;
    }
    Object.defineProperty(BootstrapDirective.prototype, "ifValue", {
        set: function (value) {
            if (value) {
                var display = 'block';
                if (this._display) {
                    display = this._display;
                }
                this.setStyle('display', display);
            }
            else if (value === false) {
                this._display = this.getStyle('display');
                this.setStyle('display', 'none');
            }
        },
        enumerable: true,
        configurable: true
    });
    BootstrapDirective.prototype.ngOnInit = function () {
        for (var _i = 0, _a = this.initClasses; _i < _a.length; _i++) {
            var cssClass = _a[_i];
            this.addClass(cssClass);
        }
        if (this.allowedTags.indexOf(this.elementRef.nativeElement.tagName) === -1) {
            throw new Error("this directive can not used on '" + this.elementRef.nativeElement.tagName + "' elements");
        }
    };
    BootstrapDirective.prototype.addClass = function (cssClass) {
        this.renderer.addClass(this.elementRef.nativeElement, cssClass);
    };
    BootstrapDirective.prototype.removeClass = function (cssClass) {
        this.renderer.removeClass(this.elementRef.nativeElement, cssClass);
    };
    BootstrapDirective.prototype.setAttribute = function (attribute, value) {
        this.renderer.setAttribute(this.elementRef.nativeElement, attribute, value);
    };
    BootstrapDirective.prototype.removeAttribute = function (attribute) {
        this.renderer.removeAttribute(this.elementRef.nativeElement, attribute);
    };
    BootstrapDirective.prototype.setStyle = function (style, value) {
        this.renderer.setStyle(this.elementRef.nativeElement, style, value);
    };
    BootstrapDirective.prototype.getStyle = function (style) {
        return this.elementRef.nativeElement.style[style] || '';
    };
    BootstrapDirective.prototype.setProperty = function (name, value) {
        this.renderer.setProperty(this.elementRef.nativeElement, name, value);
    };
    BootstrapDirective.prototype.setValue = function (value) {
        this.renderer.setValue(this.elementRef.nativeElement, value);
    };
    return BootstrapDirective;
}());
export { BootstrapDirective };
BootstrapDirective.propDecorators = {
    'ifValue': [{ type: Input, args: ['if',] },],
};
//# sourceMappingURL=bootstrap.directive.js.map